@@ -67,7 +67,7 @@ class TestPsycopg3TZField(ModelTestCase):
 
     @skip_if(os.environ.get('CI'), 'running in ci mode, skipping')
     def test_tz_field(self):
-        self.database.set_time_zone('us/eastern')
+        self.database.set_time_zone('America/New_York')
 
         # Our naive datetime is treated as if it were in US/Eastern.
         dt = datetime.datetime(2019, 1, 1, 12)
@@ -104,7 +104,7 @@ class TestPsycopg3TZField(ModelTestCase):
         self.assertEqual(tzq2.id, tz2.id)
 
         # Change the connection timezone?
-        self.database.set_time_zone('us/central')
+        self.database.set_time_zone('America/Chicago')
         tz_db = TZModel[tz.id]
         self.assertEqual(tz_db.dt.timetuple()[:4], (2019, 1, 1, 11))
         self.assertEqual(tz_db.dt.utctimetuple()[:4], (2019, 1, 1, 17))
